package com.xzzn.ems.mapper;

import java.util.List;
import com.xzzn.ems.domain.EmsFaultProtectionPlan;
import org.apache.ibatis.annotations.Param;

/**
 * 故障告警保护方案Mapper接口
 *
 * @author xzzn
 * @date 2025-10-24
 */
public interface EmsFaultProtectionPlanMapper
{
    /**
     * 查询故障告警保护方案
     *
     * @param id 故障告警保护方案主键
     * @return 故障告警保护方案
     */
    public EmsFaultProtectionPlan selectEmsFaultProtectionPlanById(Long id);

    /**
     * 查询故障告警保护方案列表
     *
     * @param emsFaultProtectionPlan 故障告警保护方案
     * @return 故障告警保护方案集合
     */
    public List<EmsFaultProtectionPlan> selectEmsFaultProtectionPlanList(EmsFaultProtectionPlan emsFaultProtectionPlan);

    /**
     * 新增故障告警保护方案
     *
     * @param emsFaultProtectionPlan 故障告警保护方案
     * @return 结果
     */
    public int insertEmsFaultProtectionPlan(EmsFaultProtectionPlan emsFaultProtectionPlan);

    /**
     * 修改故障告警保护方案
     *
     * @param emsFaultProtectionPlan 故障告警保护方案
     * @return 结果
     */
    public int updateEmsFaultProtectionPlan(EmsFaultProtectionPlan emsFaultProtectionPlan);

    /**
     * 删除故障告警保护方案
     *
     * @param id 故障告警保护方案主键
     * @return 结果
     */
    public int deleteEmsFaultProtectionPlanById(Long id);

    /**
     * 批量删除故障告警保护方案
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEmsFaultProtectionPlanByIds(Long[] ids);

    // 根据站点+faultName+faultLevel 同步删除
    public void deleteEmsFaultProtectionPlan(@Param("siteId")String siteId,
                                             @Param("faultName")String faultName,
                                             @Param("faultLevel")Integer faultLevel);
}
